* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Integration API Tutorials](https://help.sap.com/docs/leanix/ea/integration-api-tutorials)
  * Importing and Updating Fact Sheets
